@@ -145,8 +145,6 @@ class ModelMeta(type):
                 self.ignore_none_field = True
                 self.to_lowercase = False
                 self._referenceDoc = None
-                self._firestore_create_time = None
-                self._firestore_update_time = None
 
             # Attached manager to model class
             # later on manager can be accessible via class `collection` attribute
@@ -335,6 +333,8 @@ class ModelMeta(type):
         # Both Model user and student now contains the name field
         #
         for b in base:
+            if not hasattr(b, '_meta'):
+                continue
             if not b._meta.abstract:
                 from fireo.models import Model
                 if b != Model:
